https://fedorahosted.org/freeipa/ticket/5842


Patch attached.

From d4092afc1dec882d6d49ae821a4da97f3fa8921e Mon Sep 17 00:00:00 2001
From: Martin Basti <mba...@redhat.com>
Date: Thu, 23 Jun 2016 16:49:32 +0200
Subject: [PATCH] Increase ipa-getkeytab LDAP timeout to 100sec

On slower machines, the original time 10s is not enough. Raising timeout
to 100sec should help.

https://fedorahosted.org/freeipa/ticket/5842
---
 client/ipa-getkeytab.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/client/ipa-getkeytab.c b/client/ipa-getkeytab.c
index d4925865393ea19705d5d9ae09847966402fd8f0..0f549a5cf0ba047b14f6017845345f7b9138c194 100644
--- a/client/ipa-getkeytab.c
+++ b/client/ipa-getkeytab.c
@@ -267,8 +267,8 @@ static int ipa_ldap_extended_op(LDAP *ld, const char *reqoid,
         return ret;
     }
 
-    /* wait max 10 secs for the answer */
-    tv.tv_sec = 10;
+    /* wait max 100 secs for the answer */
+    tv.tv_sec = 100;
     tv.tv_usec = 0;
     ret = ldap_result(ld, msgid, 1, &tv, &res);
     if (ret == -1) {
-- 
2.5.5

-- 
Manage your subscription for the Freeipa-devel mailing list:
https://www.redhat.com/mailman/listinfo/freeipa-devel
Contribute to FreeIPA: http://www.freeipa.org/page/Contribute/Code

Reply via email to